@@ -5,7 +5,7 @@ test_that("query_parameters() returns proper list of info", {
                                           par = c("T2M"),
                                           temporal_api = "Daily")
 
-            expect_is(par_query, "list")
+            expect_type(par_query, "list")
             expect_length(par_query, 1)
             expect_named(par_query, "T2M")
           })
@@ -13,7 +13,7 @@ test_that("query_parameters() returns proper list of info", {
 test_that("query_parameters() returns list of parameter information", {
   skip_on_cran()
   par_query <- query_parameters(par = "T2M")
-  expect_is(par_query, "list")
+  expect_type(par_query, "list")
   expect_length(par_query, 1)
   expect_named(par_query, "T2M")
 })
